document.addEventListener('DOMContentLoaded', () => {
  const asciiInput = document.getElementById('asciiInput');
  const binaryOutput = document.getElementById('binaryOutput');
  const convertBtn = document.getElementById('convertBtn');
  const copyBtn = document.getElementById('copyBtn');

  function asciiToBinary(text) {
    return text.split('').map(char => {
      return char.charCodeAt(0).toString(2).padStart(8, '0');
    }).join(' ');
  }

  function convert() {
    const input = asciiInput.value;
    const binary = asciiToBinary(input);
    binaryOutput.value = binary;
  }

  async function copyToClipboard() {
    try {
      await navigator.clipboard.writeText(binaryOutput.value);
      const originalText = copyBtn.textContent;
      copyBtn.textContent = 'Copied!';
      setTimeout(() => {
        copyBtn.textContent = originalText;
      }, 2000);
    } catch (err) {
      console.error('Failed to copy text: ', err);
    }
  }

  // Event Listeners
  convertBtn.addEventListener('click', convert);
  copyBtn.addEventListener('click', copyToClipboard);
  
  // Auto-convert on input with debounce
  let timeout;
  asciiInput.addEventListener('input', () => {
    clearTimeout(timeout);
    timeout = setTimeout(convert, 500);
  });

  // Accessibility: Enable keyboard navigation
  asciiInput.addEventListener('keydown', (e) => {
    if (e.key === 'Enter' && e.ctrlKey) {
      convert();
    }
  });
});
